@@ -73,13 +73,12 @@ package Crypt::Eksblowfish::Uklblowfish;
 use warnings;
 use strict;
 
-use XSLoader;
+our $VERSION = "0.006";
 
-our $VERSION = "0.004";
+use parent "Crypt::Eksblowfish::Subkeyed";
 
-use base "Crypt::Eksblowfish::Subkeyed";
-
-XSLoader::load("Crypt::Eksblowfish", $VERSION);
+die "mismatched versions of Crypt::Eksblowfish modules"
+	unless $Crypt::Eksblowfish::Subkeyed::VERSION eq $VERSION;
 
 =head1 CLASS METHODS
 
@@ -99,7 +98,7 @@ handled specially by C<Crypt::CBC>.
 
 =cut
 
-sub keysize($) { 0 }
+sub keysize { 0 }
 
 =head1 CONSTRUCTOR
 
@@ -164,7 +163,8 @@ Modifications and Perl interface by Andrew Main (Zefram)
 
 =head1 COPYRIGHT
 
-Copyright (C) 2006, 2007, 2008 Andrew Main (Zefram) <zefram@fysh.org>
+Copyright (C) 2006, 2007, 2008, 2009
+Andrew Main (Zefram) <zefram@fysh.org>
 
 The original Eksblowfish code (in the form of crypt()) from which
 this module is derived is in the public domain.  It may be found at
